@@ -1,7 +1,7 @@
 #
 # -*- Perl -*-
-# $Id: deb.pl,v 1.5.4.3 2004/03/20 15:48:30 usu Exp $
-# Copyright (C) 2000,2001,2002,2004 Namazu Project All rights reserved ,
+# $Id: deb.pl,v 1.5.4.9 2007/01/14 04:12:04 opengl2772 Exp $
+# Copyright (C) 2000-2007 Namazu Project All rights reserved ,
 #     This is free software with ABSOLUTELY NO WARRANTY.
 #
 #  This program is free software; you can redistribute it and/or modify
@@ -28,6 +28,7 @@ require 'util.pl';
 require 'gfilter.pl';
 
 my $dpkgpath = undef;
+my @dpkgopts = undef;
 
 sub mediatype() {
     return ('application/x-deb');
@@ -35,6 +36,7 @@ sub mediatype() {
 
 sub status() {
     $dpkgpath = util::checkcmd('dpkg');
+    @dpkgopts = ("--info");
     return 'no' unless (defined $dpkgpath);
     return 'yes';
 }
@@ -54,39 +56,66 @@ sub post_codeconv () {
 sub add_magic ($) {
     my ($magic) = @_;
 
+    # FIXME: very ad hoc.
     $magic->addFileExts('\\.deb$', 'application/x-deb');
     return;
 }
 
 sub filter ($$$$$) {
     my ($orig_cfile, $cont, $weighted_str, $headings, $fields)
-      = @_;
+	= @_;
     my $cfile = defined $orig_cfile ? $$orig_cfile : '';
 
-    my $tmpfile = util::tmpnam('NMZ.deb');
-
     util::vprint("Processing deb file ... (using  '$dpkgpath')\n");
 
-    #FIXME: needed more smart solutions.
-    util::systemcmd("env LC_ALL=$util::LANG LANGUAGE=$util::LANG $dpkgpath --info " . quotemeta($cfile) . " > $tmpfile");
-
-    my $fh = util::efopen("$tmpfile");
-    my $size = util::filesize($fh);
-    if ($size > $conf::FILE_SIZE_MAX) {
-        unlink($tmpfile);
-	return 'too_large_dpkg_file';
+    my $tmpfile = util::tmpnam('NMZ.deb');
+    {	
+	my $fh = util::efopen("> $tmpfile");
+	print $fh $$cont;
+        util::fclose($fh);
     }
-    $$cont = util::readfile($fh);
-    undef $fh;
-    unlink($tmpfile);
+    {
+        my %env = (
+            "LC_ALL" => $util::LANG,
+            "LANGUAGE" => $util::LANG,
+        ); 
+	my @cmd = ($dpkgpath, @dpkgopts, $tmpfile);
+        my $fh_out = IO::File->new_tmpfile();
+        my $status = util::syscmd(
+            command => \@cmd,
+            option => {
+                "stdout" => $fh_out,
+                "stderr" => "/dev/null",
+            },
+            env => \%env,
+        );
+	my $size = util::filesize($fh_out);
+	if ($size == 0) {
+            util::fclose($fh_out);
+            unlink $tmpfile;
+	    return "Unable to convert file ($dpkgpath error occurred)";
+	}
+	if ($size > $conf::FILE_SIZE_MAX) {
+            util::fclose($fh_out);
+            unlink $tmpfile;
+	    return 'Too large deb file';
+	}
+	$$cont = util::readfile($fh_out);
+        util::fclose($fh_out);
+    }
+    unlink $tmpfile;
+
+    codeconv::normalize_document($cont);
 
     dpkg_filter($cont, $weighted_str, $fields, $headings);
 
     gfilter::line_adjust_filter($cont);
     gfilter::line_adjust_filter($weighted_str);
     gfilter::white_space_adjust_filter($cont);
+    $fields->{'title'} = gfilter::filename_to_title($cfile, $weighted_str)
+	unless $fields->{'title'};
     gfilter::show_filter_debug_info($cont, $weighted_str,
-			   $fields, $headings);
+				    $fields, $headings);
 
     return undef;
 }
