@@ -1,9 +1,9 @@
 #
 # -*- Perl -*-
-# $Id: olepowerpoint.pl,v 1.8.4.11 2005/06/06 07:07:34 opengl2772 Exp $
+# $Id: olepowerpoint.pl,v 1.8.4.19 2007/01/18 08:51:03 opengl2772 Exp $
 # Copyright (C) 1999 Jun Kurabe,
 #               1999 Ken-ichi Hirose,
-#               2004-2005 Namazu Project All rights reserved.
+#               2004-2007 Namazu Project All rights reserved.
 #     This is free software with ABSOLUTELY NO WARRANTY.
 #
 #  This program is free software; you can redistribute it and/or modify
@@ -52,19 +52,57 @@ no strict 'refs';  # for symbolic reference: $fields;
 require 'util.pl';
 require 'gfilter.pl';
 
+my $version = 0;
+
 sub mediatype() {
-    return ('application/powerpoint');
+    status();
+
+    if ($version >= 10) {
+        # 12.0 Office 2007
+        # 11.0 Office 2003
+        # 10.0 Office 2002
+        return (
+            'application/powerpoint',
+            'application/vnd.openxmlformats-officedocument.presentationml',
+        );
+    } else {
+        #  9.0 Office 2000
+        #  8.0 Office 97, 98
+        return (
+            'application/powerpoint',
+        );
+    }
 }
 
 sub status() {
+    my $const = undef;
+
     open (SAVEERR,">&STDERR");
     open (STDERR,">nul");
-    my $const;
-    $const = Win32::OLE::Const->Load("Microsoft PowerPoint 11.0 Object Library");
-    $const = Win32::OLE::Const->Load("Microsoft PowerPoint 10.0 Object Library") unless $const;
-    $const = Win32::OLE::Const->Load("Microsoft PowerPoint 9.0 Object Library") unless $const;
-    $const = Win32::OLE::Const->Load("Microsoft PowerPoint 8.0 Object Library") unless $const;
+
+    if (!defined $const) {
+        $const = Win32::OLE::Const->Load("Microsoft PowerPoint 12.0 Object Library");
+        $version = 12;
+    }
+    if (!defined $const) {
+        $const = Win32::OLE::Const->Load("Microsoft PowerPoint 11.0 Object Library");
+        $version = 11;
+    }
+    if (!defined $const) {
+        $const = Win32::OLE::Const->Load("Microsoft PowerPoint 10.0 Object Library");
+        $version = 10;
+    }
+    if (!defined $const) {
+        $const = Win32::OLE::Const->Load("Microsoft PowerPoint 9.0 Object Library");
+        $version = 9;
+    }
+    if (!defined $const) {
+        $const = Win32::OLE::Const->Load("Microsoft PowerPoint 8.0 Object Library");
+        $version = 8;
+    }
+
     open (STDERR,">&SAVEERR");
+
     return 'yes' if (defined $const);
     return 'no';
 }
@@ -84,7 +122,9 @@ sub post_codeconv () {
 sub add_magic ($) {
     my ($magic) = @_;
 
+    # FIXME: very ad hoc.
     $magic->addFileExts('\\.pp[st]$', 'application/powerpoint');
+    $magic->addFileExts('\\.pp[st]x$', 'application/vnd.openxmlformats-officedocument.presentationml');
     return;
 }
 
@@ -232,7 +272,8 @@ sub ReadPPT ($$$$) {
     # Redirect stderr to null device, to ignore Error and Exception message.
     open (SAVEERR,">&STDERR");
     open (STDERR,">nul");
-    # Load Office 97/98/2000/XP/2003 Constant
+    # Load Office 97/98/2000/XP/2003/2007 Constant
+    $office_consts = Win32::OLE::Const->Load("Microsoft Office 12.0 Object Library") unless $office_consts;
     $office_consts = Win32::OLE::Const->Load("Microsoft Office 11.0 Object Library") unless $office_consts;
     $office_consts = Win32::OLE::Const->Load("Microsoft Office 10.0 Object Library") unless $office_consts;
     $office_consts = Win32::OLE::Const->Load("Microsoft Office 9.0 Object Library") unless $office_consts;
