@@ -2,10 +2,10 @@
  * 
  * codeconv.c -
  * 
- * $Id: codeconv.c,v 1.29.8.5 2005/09/02 09:23:45 opengl2772 Exp $
+ * $Id: codeconv.c,v 1.29.8.6 2007/01/22 05:58:19 opengl2772 Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000-2005 Namazu Project All rights reserved.
+ * Copyright (C) 2000-2007 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -249,7 +249,7 @@ euctosjis(uchar *s)
 		break;
 	    }
 	    if (nmz_iseuc(c2)) {
-		c = jistojms(c & 0x7f, c2 & 0x7f);
+		c = jistojms((uchar)(c & 0x7f), (uchar)(c2 & 0x7f));
 		*(s + i++) = c;
 		*(s + i++) = kanji2nd;
 	    } else {
