@@ -2,10 +2,10 @@
  * 
  * idxname.c - Idx handling routines.
  *
- * $Id: idxname.c,v 1.25.8.6 2005/07/21 08:47:54 opengl2772 Exp $
+ * $Id: idxname.c,v 1.25.8.7 2006/04/15 17:44:18 opengl2772 Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000,2001,2003 Namazu Project All rights reserved.
+ * Copyright (C) 2000-2006 Namazu Project All rights reserved.
  * Copyright (C) 1999 NOKUBI Takatsugu All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
@@ -154,7 +154,7 @@ nmz_complete_idxnames(void)
 
     for (i = 0; i < indices.num; i++) {
  	if (*indices.names[i] == '+' && 
-	    isalnum((unsigned char)*(indices.names[i] + 1))) {
+	    nmz_isalnum((unsigned char)*(indices.names[i] + 1))) {
 	    char *tmp;
 	    tmp = malloc(strlen(defaultidx) 
 				  + 1 + strlen(indices.names[i]) + 1);
