@@ -2,10 +2,10 @@
  * 
  * re.c -
  * 
- * $Id: re.c,v 1.32.8.10 2005/11/02 16:58:56 opengl2772 Exp $
+ * $Id: re.c,v 1.32.8.13 2006/09/19 15:21:58 opengl2772 Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000-2005 Namazu Project All rights reserved.
+ * Copyright (C) 2000-2006 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -135,10 +135,13 @@ nmz_regex_grep_standard(struct re_pattern_buffer *rp, FILE *fp)
             /* Matched */
             tmp = nmz_get_hlist(i);
             if (tmp.stat == ERR_FATAL) {
+                nmz_free_hlist(val);
 	        return tmp;
             }
             if (tmp.num > maxhit) {
+                nmz_free_hlist(tmp);
                 nmz_free_hlist(val);
+                val.data = NULL;
                 val.stat = ERR_TOO_MUCH_HIT;
                 break;
             }
@@ -146,7 +149,9 @@ nmz_regex_grep_standard(struct re_pattern_buffer *rp, FILE *fp)
             if (tmp.num > 0) {
                 n++;
                 if (n > maxmatch) {
+                    nmz_free_hlist(tmp);
                     nmz_free_hlist(val);
+                    val.data = NULL;
                     val.stat = ERR_TOO_MUCH_MATCH;
                     return val;
                 }
@@ -157,6 +162,7 @@ nmz_regex_grep_standard(struct re_pattern_buffer *rp, FILE *fp)
                 }
                 if (val.num > maxhit) {
                     nmz_free_hlist(val);
+                    val.data = NULL;
                     val.stat = ERR_TOO_MUCH_HIT;
                     break;
                 }
@@ -231,6 +237,7 @@ nmz_regex_grep_field(struct re_pattern_buffer *rp, FILE *fp, const char *field)
                 nmz_set_dyingmsg(nmz_msg("%s: %s", NMZ.t, strerror(errno)));
                 fclose(date_index);
                 nmz_free_hlist(val);
+                val.data = NULL;
                 val.stat = ERR_FATAL;
                 return val; /* error */
             }
@@ -244,6 +251,7 @@ nmz_regex_grep_field(struct re_pattern_buffer *rp, FILE *fp, const char *field)
             if (n > maxhit) {
                 fclose(date_index);
                 nmz_free_hlist(val);
+                val.data = NULL;
                 val.stat = ERR_TOO_MUCH_HIT;
                 return val;
             }
