@@ -2,10 +2,10 @@
  * 
  * replace.c - 
  *
- * $Id: replace.c,v 1.15.8.3 2001/12/21 05:36:40 knok Exp $
+ * $Id: replace.c,v 1.15.8.6 2004/03/20 15:25:10 usu Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000,2001 Namazu Project All rights reserved.
+ * Copyright (C) 2000,2001,2003,2004 Namazu Project All rights reserved.
  * Copyright (C) 1999 NOKUBI Takatsugu All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
@@ -84,7 +84,7 @@ int
 nmz_replace_uri(char *uri)
 {
     int npat, nrep, i, j;
-    char tmp[BUFSIZE];
+    char tmp[BUFSIZE] = "";
     struct nmz_replace *list = replaces;
     int is_regex_matching = 0;
 
@@ -198,12 +198,15 @@ nmz_add_replace(const char *pat, const char *rep)
     newp->pat = malloc(strlen(pat) + 1);
     if (newp->pat == NULL) {
 	 nmz_set_dyingmsg(nmz_msg("%s", strerror(errno)));
+         free(newp);
 	 return FAILURE;
     }
 
     newp->rep = malloc(strlen(rep) + 1);
     if (newp->rep == NULL) {
 	 nmz_set_dyingmsg(nmz_msg("%s", strerror(errno)));
+         free(newp->pat);
+         free(newp);
 	 return FAILURE;
     }
 
