@@ -1,6 +1,6 @@
 /*
  * 
- * $Id: util.c,v 1.75.4.16 2006/02/05 18:53:30 opengl2772 Exp $
+ * $Id: util.c,v 1.75.4.17 2006/04/15 17:44:18 opengl2772 Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000-2006 Namazu Project All rights reserved.
@@ -359,7 +359,7 @@ nmz_isnumstr(const char *str)
     }
 
     for (p = (const unsigned char *)str; *p != '\0'; p++) {
-	if (! isdigit((int)*p)) {
+	if (!nmz_isdigit((int)*p)) {
 	    return 0;
 	}
     }
