@@ -2,10 +2,10 @@
  * 
  * var.c -
  * 
- * $Id: var.c,v 1.21 2000/12/18 08:14:31 knok Exp $
+ * $Id: var.c,v 1.21.4.2 2004/03/20 15:25:10 usu Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000 Namazu Project All rights reserved.
+ * Copyright (C) 2000,2002 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -51,6 +51,7 @@ struct nmz_names NMZ = {  /* NMZ.* files' names */
     "NMZ.pi",
     "NMZ.tips",
     "NMZ.access",
-    "NMZ.version"
+    "NMZ.version",
+    "NMZ.warnlog"
 };
 
