@@ -32,7 +32,8 @@ $ALLOW_FILE =	".*\\.(?:$HTML_SUFFIX)|.*\\.txt" . # HTML, plain text
 		"|.*\\.tex|.*\\.dvi" .   	   # TeX, DVI
 		"|.*\\.rpm|.*\\.deb" .   	   # RPM, DEB
 		"|.*\\.doc|.*\\.xls|.*\\.pp[st]" . # Word, Excel, PowerPoint
-                "|.*\\.vs[dst]|.*\\.v[dst]x" .     # Visio
+		"|.*\\.docx|.*\\.xlsx|.*\\.pp[st]x" . # MS-OfficeOpenXML Word, Excel, PowerPoint
+		"|.*\\.vs[dst]|.*\\.v[dst]x" .     # Visio
 		"|.*\\.j[sabf]w|.*\\.jtd" .        # Ichitaro 4, 5, 6, 7, 8
 		"|.*\\.sx[widc]" .                 # OpenOffice Writer,Calc,Impress,Draw
 		"|.*\\.od[tspg]" .                 # OpenOffice2.0
@@ -42,7 +43,7 @@ $ALLOW_FILE =	".*\\.(?:$HTML_SUFFIX)|.*\\.txt" . # HTML, plain text
 		"|.*\\.gnumeric" .                 # Gnumeric
 		"|.*\\.kwd|.*\\.ksp" .             # KWord, KSpread
 		"|.*\\.kpr|.*\\.flw" .             # KPresenter, Kivio
-		"|\\d+|[-\\w]+\\.[1-9n]";          # Mail/News, man
+		"|.*\\.eml|\\d+|[-\\w]+\\.[1-9n]"; # Mail/News, man
 
 #
 # This pattern specifies file names which will NOT be targeted.
