@@ -1,6 +1,6 @@
 #
 # -*- Perl -*-
-# $Id: wakati.pl,v 1.9.8.8 2006/01/23 09:18:24 opengl2772 Exp $
+# $Id: wakati.pl,v 1.9.8.9 2006/03/10 16:25:32 opengl2772 Exp $
 # Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
 # Copyright (C) 2000-2006 Namazu Project All rights reserved.
 #     This is free software with ABSOLUTELY NO WARRANTY.
@@ -94,7 +94,7 @@ sub wakatize_japanese_sub ($) {
 		$t->DESTROY() if defined $t;
 	    }; 
             $str = $$content;
-	    $str =~ s/([\x80-\xff]+)/{my $text = $t->parse($1); " $text ";}/ge;
+            $str =~ s/([\x80-\xff]+)/{my $s = $1; my $text = $t->parse($s); " $text ";}/ge;
 	} else {
 	    util::cdie(_("invalid wakati module: ")."$module\n");
 	}
