@@ -2,10 +2,10 @@
  * 
  * namazu.c - search client of Namazu
  *
- * $Id: namazu-cmd.c,v 1.17.4.2 2001/09/02 07:13:38 rug Exp $
+ * $Id: namazu-cmd.c,v 1.17.4.9 2005/11/10 22:01:57 opengl2772 Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000 Namazu Project All rights reserved.
+ * Copyright (C) 2000-2005 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -73,7 +73,6 @@
 #include "var.h"
 #include "result.h"
 #include "system.h"
-#include "namazu.h"
 
 /*
  * Extern variables.
@@ -104,7 +103,7 @@ ck_atoi (char const *str, int *out)
 	if (*p < '0' || *p > '9')
 	    return -1;
 
-    *out = atoi (optarg);
+    *out = atoi (nmz_optarg);
     return 0;
 }
 
@@ -136,8 +135,9 @@ stdio2file(const char * fname)
 /*
  * Command line options.
  */
-static const char *short_options = "01:2345acCedf:FhHlL:n:o:qrRsSUvw:";
+static const char *short_options = "01:234:5acCedf:FhHlL:n:o:qrRsSUvw:";
 static struct option long_options[] = {
+    { "norc",             no_argument,       NULL, 1 },
     { "help",             no_argument,       NULL, '0' },
     { "result",           required_argument, NULL, '1' },
     { "late",             no_argument,       NULL, '2' },
@@ -176,17 +176,23 @@ parse_options(int argc, char **argv)
     int opt_show_config = 0;
 
     for (;;) {
-        int ch = getopt_long(argc, argv, short_options, long_options, NULL);
-        if (ch == EOF) {
+        int ch = nmz_getopt_long(argc, argv, short_options, long_options, NULL);
+        if (ch == -1) {
             break;
 	}
 	switch (ch) {
+        case 1:
+            set_namazunorc("all");
+            break;
 	case '0':
 	    show_usage();
 	    exit(EXIT_SUCCESS);
 	    break;
-	case '1':
-	    set_templatesuffix(optarg);
+	case '1':  /* --result */
+            if (nmz_optarg == NULL) {
+                die("%s: invalid argument for -1 --result", nmz_optarg);
+            }
+	    set_templatesuffix(nmz_optarg);
 	    break;
 	case '2':
 	    nmz_set_sortmethod(SORT_BY_DATE);
@@ -198,31 +204,39 @@ parse_options(int argc, char **argv)
 	    break;
 	case '4':  /* --sort */
 	{
-	    if (strcasecmp(optarg, "score") == 0) {
-		nmz_set_sortmethod(SORT_BY_SCORE);
-	    } else if (strcasecmp(optarg, "date") == 0) {
-		nmz_set_sortmethod(SORT_BY_DATE);
-	    } else if (nmz_strprefixcasecmp(optarg, "field:") == 0) {
-		nmz_set_sortmethod(SORT_BY_FIELD);
-		nmz_set_sortfield(optarg + strlen("field:"));
-	    }
+            if (nmz_optarg == NULL) {
+                die("%s: invalid argument for -4 --sort", nmz_optarg);
+            }
+	    if (strcasecmp(nmz_optarg, "score") == 0) {
+                nmz_set_sortmethod(SORT_BY_SCORE);
+	    } else if (strcasecmp(nmz_optarg, "date") == 0) {
+                nmz_set_sortmethod(SORT_BY_DATE);
+	    } else if (nmz_strprefixcasecmp(nmz_optarg, "field:") == 0) {
+                nmz_set_sortmethod(SORT_BY_FIELD);
+                nmz_set_sortfield(nmz_optarg + strlen("field:"));
+            } else {
+                die("%s: invalid argument for -4 --sort", nmz_optarg);
+            }
 	}
 	break;
 	case '5':  /* --ascending */
 	    nmz_set_sortorder(ASCENDING);
 	    break;
-	case 'f':
-	    set_namazurc(optarg);
+	case 'f':  /* --config */
+            if (nmz_optarg == NULL) {
+                die("%s: invalid argument for -f --config", nmz_optarg);
+            }
+	    set_namazurc(nmz_optarg);
 	    break;
 	case 'n':
-	    if (ck_atoi(optarg, &tmp)) {
-		die("%s: invalid argument for -n, --max", optarg);
+	    if (ck_atoi(nmz_optarg, &tmp)) {
+		die("%s: invalid argument for -n, --max", nmz_optarg);
 	    }
 	    set_maxresult(tmp);
 	    break;
 	case 'w':
-	    if (ck_atoi(optarg, &tmp)) {
-		die("%s: invalid argument for -w, --whence", optarg);
+	    if (ck_atoi(nmz_optarg, &tmp)) {
+		die("%s: invalid argument for -w, --whence", nmz_optarg);
 	    }
 	    set_listwhence(tmp);
 	    break;
@@ -271,8 +285,11 @@ parse_options(int argc, char **argv)
 	case 'C':
 	    opt_show_config = 1;
 	    break;
-	case 'o':
-	    stdio2file(optarg);
+	case 'o':  /* --output */
+            if (nmz_optarg == NULL) {
+                die("%s: invalid argument for -o --output", nmz_optarg);
+            }
+	    stdio2file(nmz_optarg);
 	    break;
 	}
     } 
@@ -284,13 +301,12 @@ parse_options(int argc, char **argv)
 	exit(EXIT_SUCCESS);
     }
 
-    return optind;
+    return nmz_optind;
 }
 
 int 
 main(int argc, char **argv)
 {
-    int i = 0;
     char query[BUFSIZE] = "", subquery[BUFSIZE] = "";
     char *localedir = getenv("NAMAZULOCALEDIR");
 
@@ -326,6 +342,8 @@ main(int argc, char **argv)
 	show_mini_usage();
 	exit(EXIT_FAILURE);
     } else {
+        int i = 0;
+
 	set_refprint(1);
 
 	i = parse_options(argc, argv); 
@@ -339,7 +357,7 @@ main(int argc, char **argv)
 	    return 1;
 	}
 
-        strcpy(query, argv[i++]);
+        strncpy(query, argv[i++], BUFSIZE - 1);
         if (i < argc) {
 	    int curidx = nmz_get_idxnum();
             for (curidx = 0; i < argc && curidx < INDEX_MAX; i++) {
@@ -362,7 +380,7 @@ main(int argc, char **argv)
     if (nmz_get_idxnum() == 0) {
 	/* Use defaultidx for the taget index. */
 	if (nmz_add_index(nmz_get_defaultidx()) != SUCCESS) {
-	    die("invalid idxname: %s", argv[i]);
+	    die("invalid idxname: %s", nmz_get_defaultidx());
 	}
     }
 
