@@ -1,9 +1,9 @@
 /*
  * 
- * $Id: rcfile.c,v 1.31.4.12 2005/11/10 22:01:57 opengl2772 Exp $
+ * $Id: rcfile.c,v 1.31.4.14 2007/02/25 03:34:53 opengl2772 Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
- * Copyright (C) 2000-2005 Namazu Project All rights reserved.
+ * Copyright (C) 2000-2007 Namazu Project All rights reserved.
  * This is free software with ABSOLUTELY NO WARRANTY.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -403,7 +403,7 @@ get_rc_arg(const char *line, char *arg)
     arg[BUFSIZE - 1] = '\0';
     *arg = '\0';
     if (*line != '"') {
-	int n = strcspn(line, " \t");
+	size_t n = strcspn(line, " \t");
 	if (n >= BUFSIZE) n = BUFSIZE - 1;
 	strncpy(arg, line, n);
 	arg[n] = '\0';     /* Hey, don't forget this after strncpy()! */
@@ -413,7 +413,7 @@ get_rc_arg(const char *line, char *arg)
 	line++;
 	n = 1;
 	do {
-	    int nn = strcspn(line, "\"\\");
+	    size_t nn = strcspn(line, "\"\\");
 	    if (nn >= (BUFSIZE - strlen(arg))) nn = BUFSIZE - strlen(arg) - 1;
 	    strncat(arg, line, nn);
 	    n += nn;
